#ifndef PCRIO_H_
#define PCRIO_H_

//////////////////////////////////////////////////////////////////
// PcrIO is responsible for sending and receiving messages with
// PCR1000. Once recieve a message, it sends signal via Qt.
//////////////////////////////////////////////////////////////////
#include <unistd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/socket.h>
#include <sys/termios.h>
#include <string.h>
#include <fcntl.h>
#include <stdio.h>
#include <error.h>
#include <asm/errno.h>

#include <qobject.h>
#include <qstring.h>
#include <qtimer.h>

#define PCRIO_BUFFERSIZE 64

class PcrIO : public QObject
{
  Q_OBJECT

public:
  PcrIO( QObject *parent=0, const char *name=0 );
  ~PcrIO();
  
  bool highPriority () const;
  bool Open( const char *device, tcflag_t baudrate );
  bool Close();

public slots:
  void sendMessageSlot( const char *mesg, int len );

signals:
  void connected();
  void closed();
  void disconnected();
  void radioMessage( const char *mesg, int len );
  void messageSent();

protected:
  void timerEvent( QTimerEvent * );
  bool ReadWrite();
  bool IsTokenComplete( const char *data, int len, int *first, int *tokenlen );

private:
  int fd;
  fd_set rset, wset;
  struct termios tio;

  int timerId;
  int bytesToWrite;
  char bufferRead[PCRIO_BUFFERSIZE];
  char bufferWrite[PCRIO_BUFFERSIZE];
  char mesg[PCRIO_BUFFERSIZE];

  int bufferReadLen;
};

#endif // PCRIO_H_
